==> blender_2.37a.orig.tar.gz: blender-2.37a.orig/source/blender/python/api2_2x/sceneRadio.h <==
/* 
 * $Id: sceneRadio.h,v 1.2 2004/09/25 20:30:40 stiv Exp $
 *
 * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version. The Blender
 * Foundation also sells licenses for use in proprietary software under
 * the Blender License.  See http://www.blender.org/BL/ for information
 * about this.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
 * All rights reserved.
 *
 * This is a new part of Blender.
 *
 * Contributor(s): Willian P. Germano
 *
 * ***** END GPL/BL DUAL LICENSE BLOCK *****
*/

#ifndef EXPP_SCENERADIO_H
#define EXPP_SCENERADIO_H

#include <Python.h>
#include <DNA_radio_types.h>
#include <DNA_scene_types.h>

/* BPy_Radio declaration */
typedef struct {
	PyObject_HEAD struct Radio *radio;
	struct Scene *scene;
} BPy_Radio;

PyObject *Radio_Init( void );

PyObject *Radio_CreatePyObject( struct Scene *scene );
int Radio_CheckPyObject( PyObject * py_obj );

#endif				/* EXPP_SCENERADIO_H */

==> blender_2.42a.orig.tar.gz: blender-2.42a/source/blender/python/api2_2x/sceneRadio.h <==
/* 
 * $Id: sceneRadio.h,v 1.3 2005/07/18 03:50:37 ascotan Exp $
 *
 * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version. The Blender
 * Foundation also sells licenses for use in proprietary software under
 * the Blender License.  See http://www.blender.org/BL/ for information
 * about this.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
 * All rights reserved.
 *
 * This is a new part of Blender.
 *
 * Contributor(s): Willian P. Germano
 *
 * ***** END GPL/BL DUAL LICENSE BLOCK *****
*/

#ifndef EXPP_SCENERADIO_H
#define EXPP_SCENERADIO_H

#include <Python.h>
#include "DNA_radio_types.h"
#include "DNA_scene_types.h"

/* BPy_Radio declaration */
typedef struct {
	PyObject_HEAD 
	struct Radio *radio;
	struct Scene *scene;
} BPy_Radio;

PyObject *Radio_Init( void );

PyObject *Radio_CreatePyObject( struct Scene *scene );
int Radio_CheckPyObject( PyObject * py_obj );

#endif				/* EXPP_SCENERADIO_H */
